# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 base_endpoint: Optional[pulumi.Input[str]] = None,
                 cloud_endpoint: Optional[pulumi.Input[str]] = None,
                 database: Optional[pulumi.Input[str]] = None,
                 default_region: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 sslmode: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] base_endpoint: The base endpoint for Materialize.
        :param pulumi.Input[str] cloud_endpoint: The endpoint for the Materialize Cloud API.
        :param pulumi.Input[str] database: The Materialize database. Can also come from the `MZ_DATABASE` environment variable. Defaults to `materialize`.
        :param pulumi.Input[str] default_region: The default region if not specified in the resource
        :param pulumi.Input[str] endpoint: The endpoint for the Materialize API.
        :param pulumi.Input[str] password: Materialize host. Can also come from the `MZ_PASSWORD` environment variable.
        :param pulumi.Input[str] sslmode: For testing purposes, the SSL mode to use.
        """
        if base_endpoint is None:
            base_endpoint = _utilities.get_env('MZ_BASE_ENDPOINT')
        if base_endpoint is not None:
            pulumi.set(__self__, "base_endpoint", base_endpoint)
        if cloud_endpoint is None:
            cloud_endpoint = _utilities.get_env('MZ_CLOUD_ENDPOINT')
        if cloud_endpoint is not None:
            pulumi.set(__self__, "cloud_endpoint", cloud_endpoint)
        if database is None:
            database = _utilities.get_env('MZ_DATABASE')
        if database is not None:
            pulumi.set(__self__, "database", database)
        if default_region is None:
            default_region = _utilities.get_env('MZ_DEFAULT_REGION')
        if default_region is not None:
            pulumi.set(__self__, "default_region", default_region)
        if endpoint is None:
            endpoint = _utilities.get_env('MZ_ENDPOINT')
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if password is None:
            password = _utilities.get_env('MZ_PASSWORD')
        if password is not None:
            pulumi.set(__self__, "password", password)
        if sslmode is None:
            sslmode = _utilities.get_env('MZ_SSLMODE')
        if sslmode is not None:
            pulumi.set(__self__, "sslmode", sslmode)

    @property
    @pulumi.getter(name="baseEndpoint")
    def base_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The base endpoint for Materialize.
        """
        return pulumi.get(self, "base_endpoint")

    @base_endpoint.setter
    def base_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "base_endpoint", value)

    @property
    @pulumi.getter(name="cloudEndpoint")
    def cloud_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The endpoint for the Materialize Cloud API.
        """
        return pulumi.get(self, "cloud_endpoint")

    @cloud_endpoint.setter
    def cloud_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloud_endpoint", value)

    @property
    @pulumi.getter
    def database(self) -> Optional[pulumi.Input[str]]:
        """
        The Materialize database. Can also come from the `MZ_DATABASE` environment variable. Defaults to `materialize`.
        """
        return pulumi.get(self, "database")

    @database.setter
    def database(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database", value)

    @property
    @pulumi.getter(name="defaultRegion")
    def default_region(self) -> Optional[pulumi.Input[str]]:
        """
        The default region if not specified in the resource
        """
        return pulumi.get(self, "default_region")

    @default_region.setter
    def default_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_region", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The endpoint for the Materialize API.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Materialize host. Can also come from the `MZ_PASSWORD` environment variable.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def sslmode(self) -> Optional[pulumi.Input[str]]:
        """
        For testing purposes, the SSL mode to use.
        """
        return pulumi.get(self, "sslmode")

    @sslmode.setter
    def sslmode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sslmode", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_endpoint: Optional[pulumi.Input[str]] = None,
                 cloud_endpoint: Optional[pulumi.Input[str]] = None,
                 database: Optional[pulumi.Input[str]] = None,
                 default_region: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 sslmode: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the materialize package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] base_endpoint: The base endpoint for Materialize.
        :param pulumi.Input[str] cloud_endpoint: The endpoint for the Materialize Cloud API.
        :param pulumi.Input[str] database: The Materialize database. Can also come from the `MZ_DATABASE` environment variable. Defaults to `materialize`.
        :param pulumi.Input[str] default_region: The default region if not specified in the resource
        :param pulumi.Input[str] endpoint: The endpoint for the Materialize API.
        :param pulumi.Input[str] password: Materialize host. Can also come from the `MZ_PASSWORD` environment variable.
        :param pulumi.Input[str] sslmode: For testing purposes, the SSL mode to use.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the materialize package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_endpoint: Optional[pulumi.Input[str]] = None,
                 cloud_endpoint: Optional[pulumi.Input[str]] = None,
                 database: Optional[pulumi.Input[str]] = None,
                 default_region: Optional[pulumi.Input[str]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 sslmode: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            if base_endpoint is None:
                base_endpoint = _utilities.get_env('MZ_BASE_ENDPOINT')
            __props__.__dict__["base_endpoint"] = base_endpoint
            if cloud_endpoint is None:
                cloud_endpoint = _utilities.get_env('MZ_CLOUD_ENDPOINT')
            __props__.__dict__["cloud_endpoint"] = cloud_endpoint
            if database is None:
                database = _utilities.get_env('MZ_DATABASE')
            __props__.__dict__["database"] = database
            if default_region is None:
                default_region = _utilities.get_env('MZ_DEFAULT_REGION')
            __props__.__dict__["default_region"] = default_region
            if endpoint is None:
                endpoint = _utilities.get_env('MZ_ENDPOINT')
            __props__.__dict__["endpoint"] = endpoint
            if password is None:
                password = _utilities.get_env('MZ_PASSWORD')
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if sslmode is None:
                sslmode = _utilities.get_env('MZ_SSLMODE')
            __props__.__dict__["sslmode"] = sslmode
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'materialize',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="baseEndpoint")
    def base_endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        The base endpoint for Materialize.
        """
        return pulumi.get(self, "base_endpoint")

    @property
    @pulumi.getter(name="cloudEndpoint")
    def cloud_endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        The endpoint for the Materialize Cloud API.
        """
        return pulumi.get(self, "cloud_endpoint")

    @property
    @pulumi.getter
    def database(self) -> pulumi.Output[Optional[str]]:
        """
        The Materialize database. Can also come from the `MZ_DATABASE` environment variable. Defaults to `materialize`.
        """
        return pulumi.get(self, "database")

    @property
    @pulumi.getter(name="defaultRegion")
    def default_region(self) -> pulumi.Output[Optional[str]]:
        """
        The default region if not specified in the resource
        """
        return pulumi.get(self, "default_region")

    @property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        The endpoint for the Materialize API.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        Materialize host. Can also come from the `MZ_PASSWORD` environment variable.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def sslmode(self) -> pulumi.Output[Optional[str]]:
        """
        For testing purposes, the SSL mode to use.
        """
        return pulumi.get(self, "sslmode")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SinkKafkaArgs', 'SinkKafka']

@pulumi.input_type
class SinkKafkaArgs:
    def __init__(__self__, *,
                 from_: pulumi.Input['SinkKafkaFromArgs'],
                 kafka_connection: pulumi.Input['SinkKafkaKafkaConnectionArgs'],
                 topic: pulumi.Input[str],
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 compression_type: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input['SinkKafkaEnvelopeArgs']] = None,
                 format: Optional[pulumi.Input['SinkKafkaFormatArgs']] = None,
                 key_not_enforced: Optional[pulumi.Input[bool]] = None,
                 keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 snapshot: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a SinkKafka resource.
        :param pulumi.Input['SinkKafkaFromArgs'] from_: The name of the source, table or materialized view you want to send to the sink.
        :param pulumi.Input['SinkKafkaKafkaConnectionArgs'] kafka_connection: The name of the Kafka connection to use in the sink.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this sink.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] compression_type: The type of compression to apply to messages before they are sent to Kafka.
        :param pulumi.Input[str] database_name: The identifier for the sink database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SinkKafkaEnvelopeArgs'] envelope: How to interpret records (e.g. Debezium, Upsert).
        :param pulumi.Input['SinkKafkaFormatArgs'] format: How to decode raw bytes from different formats into data structures it can understand at runtime.
        :param pulumi.Input[bool] key_not_enforced: Disable Materialize's validation of the key's uniqueness.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] keys: An optional list of columns to use for the Kafka key. If unspecified, the Kafka key is left unset.
        :param pulumi.Input[str] name: The identifier for the sink.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the sink schema. Defaults to `public`.
        :param pulumi.Input[bool] snapshot: Whether to emit the consolidated results of the query before the sink was created at the start of the sink.
        """
        pulumi.set(__self__, "from_", from_)
        pulumi.set(__self__, "kafka_connection", kafka_connection)
        pulumi.set(__self__, "topic", topic)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if compression_type is not None:
            pulumi.set(__self__, "compression_type", compression_type)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if envelope is not None:
            pulumi.set(__self__, "envelope", envelope)
        if format is not None:
            pulumi.set(__self__, "format", format)
        if key_not_enforced is not None:
            pulumi.set(__self__, "key_not_enforced", key_not_enforced)
        if keys is not None:
            pulumi.set(__self__, "keys", keys)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if snapshot is not None:
            pulumi.set(__self__, "snapshot", snapshot)

    @property
    @pulumi.getter(name="from")
    def from_(self) -> pulumi.Input['SinkKafkaFromArgs']:
        """
        The name of the source, table or materialized view you want to send to the sink.
        """
        return pulumi.get(self, "from_")

    @from_.setter
    def from_(self, value: pulumi.Input['SinkKafkaFromArgs']):
        pulumi.set(self, "from_", value)

    @property
    @pulumi.getter(name="kafkaConnection")
    def kafka_connection(self) -> pulumi.Input['SinkKafkaKafkaConnectionArgs']:
        """
        The name of the Kafka connection to use in the sink.
        """
        return pulumi.get(self, "kafka_connection")

    @kafka_connection.setter
    def kafka_connection(self, value: pulumi.Input['SinkKafkaKafkaConnectionArgs']):
        pulumi.set(self, "kafka_connection", value)

    @property
    @pulumi.getter
    def topic(self) -> pulumi.Input[str]:
        """
        The Kafka topic you want to subscribe to.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: pulumi.Input[str]):
        pulumi.set(self, "topic", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this sink.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="compressionType")
    def compression_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of compression to apply to messages before they are sent to Kafka.
        """
        return pulumi.get(self, "compression_type")

    @compression_type.setter
    def compression_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compression_type", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the sink database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def envelope(self) -> Optional[pulumi.Input['SinkKafkaEnvelopeArgs']]:
        """
        How to interpret records (e.g. Debezium, Upsert).
        """
        return pulumi.get(self, "envelope")

    @envelope.setter
    def envelope(self, value: Optional[pulumi.Input['SinkKafkaEnvelopeArgs']]):
        pulumi.set(self, "envelope", value)

    @property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input['SinkKafkaFormatArgs']]:
        """
        How to decode raw bytes from different formats into data structures it can understand at runtime.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input['SinkKafkaFormatArgs']]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="keyNotEnforced")
    def key_not_enforced(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable Materialize's validation of the key's uniqueness.
        """
        return pulumi.get(self, "key_not_enforced")

    @key_not_enforced.setter
    def key_not_enforced(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "key_not_enforced", value)

    @property
    @pulumi.getter
    def keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        An optional list of columns to use for the Kafka key. If unspecified, the Kafka key is left unset.
        """
        return pulumi.get(self, "keys")

    @keys.setter
    def keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "keys", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the sink.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the sink schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter
    def snapshot(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to emit the consolidated results of the query before the sink was created at the start of the sink.
        """
        return pulumi.get(self, "snapshot")

    @snapshot.setter
    def snapshot(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "snapshot", value)


@pulumi.input_type
class _SinkKafkaState:
    def __init__(__self__, *,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 compression_type: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input['SinkKafkaEnvelopeArgs']] = None,
                 format: Optional[pulumi.Input['SinkKafkaFormatArgs']] = None,
                 from_: Optional[pulumi.Input['SinkKafkaFromArgs']] = None,
                 kafka_connection: Optional[pulumi.Input['SinkKafkaKafkaConnectionArgs']] = None,
                 key_not_enforced: Optional[pulumi.Input[bool]] = None,
                 keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 snapshot: Optional[pulumi.Input[bool]] = None,
                 topic: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SinkKafka resources.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this sink.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] compression_type: The type of compression to apply to messages before they are sent to Kafka.
        :param pulumi.Input[str] database_name: The identifier for the sink database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input['SinkKafkaEnvelopeArgs'] envelope: How to interpret records (e.g. Debezium, Upsert).
        :param pulumi.Input['SinkKafkaFormatArgs'] format: How to decode raw bytes from different formats into data structures it can understand at runtime.
        :param pulumi.Input['SinkKafkaFromArgs'] from_: The name of the source, table or materialized view you want to send to the sink.
        :param pulumi.Input['SinkKafkaKafkaConnectionArgs'] kafka_connection: The name of the Kafka connection to use in the sink.
        :param pulumi.Input[bool] key_not_enforced: Disable Materialize's validation of the key's uniqueness.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] keys: An optional list of columns to use for the Kafka key. If unspecified, the Kafka key is left unset.
        :param pulumi.Input[str] name: The identifier for the sink.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the sink.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the sink schema. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this sink.
        :param pulumi.Input[bool] snapshot: Whether to emit the consolidated results of the query before the sink was created at the start of the sink.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        """
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if compression_type is not None:
            pulumi.set(__self__, "compression_type", compression_type)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if envelope is not None:
            pulumi.set(__self__, "envelope", envelope)
        if format is not None:
            pulumi.set(__self__, "format", format)
        if from_ is not None:
            pulumi.set(__self__, "from_", from_)
        if kafka_connection is not None:
            pulumi.set(__self__, "kafka_connection", kafka_connection)
        if key_not_enforced is not None:
            pulumi.set(__self__, "key_not_enforced", key_not_enforced)
        if keys is not None:
            pulumi.set(__self__, "keys", keys)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot is not None:
            pulumi.set(__self__, "snapshot", snapshot)
        if topic is not None:
            pulumi.set(__self__, "topic", topic)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this sink.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="compressionType")
    def compression_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of compression to apply to messages before they are sent to Kafka.
        """
        return pulumi.get(self, "compression_type")

    @compression_type.setter
    def compression_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compression_type", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the sink database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def envelope(self) -> Optional[pulumi.Input['SinkKafkaEnvelopeArgs']]:
        """
        How to interpret records (e.g. Debezium, Upsert).
        """
        return pulumi.get(self, "envelope")

    @envelope.setter
    def envelope(self, value: Optional[pulumi.Input['SinkKafkaEnvelopeArgs']]):
        pulumi.set(self, "envelope", value)

    @property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input['SinkKafkaFormatArgs']]:
        """
        How to decode raw bytes from different formats into data structures it can understand at runtime.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input['SinkKafkaFormatArgs']]):
        pulumi.set(self, "format", value)

    @property
    @pulumi.getter(name="from")
    def from_(self) -> Optional[pulumi.Input['SinkKafkaFromArgs']]:
        """
        The name of the source, table or materialized view you want to send to the sink.
        """
        return pulumi.get(self, "from_")

    @from_.setter
    def from_(self, value: Optional[pulumi.Input['SinkKafkaFromArgs']]):
        pulumi.set(self, "from_", value)

    @property
    @pulumi.getter(name="kafkaConnection")
    def kafka_connection(self) -> Optional[pulumi.Input['SinkKafkaKafkaConnectionArgs']]:
        """
        The name of the Kafka connection to use in the sink.
        """
        return pulumi.get(self, "kafka_connection")

    @kafka_connection.setter
    def kafka_connection(self, value: Optional[pulumi.Input['SinkKafkaKafkaConnectionArgs']]):
        pulumi.set(self, "kafka_connection", value)

    @property
    @pulumi.getter(name="keyNotEnforced")
    def key_not_enforced(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable Materialize's validation of the key's uniqueness.
        """
        return pulumi.get(self, "key_not_enforced")

    @key_not_enforced.setter
    def key_not_enforced(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "key_not_enforced", value)

    @property
    @pulumi.getter
    def keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        An optional list of columns to use for the Kafka key. If unspecified, the Kafka key is left unset.
        """
        return pulumi.get(self, "keys")

    @keys.setter
    def keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "keys", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the sink.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the sink.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the sink schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        The size of the cluster maintaining this sink.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def snapshot(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to emit the consolidated results of the query before the sink was created at the start of the sink.
        """
        return pulumi.get(self, "snapshot")

    @snapshot.setter
    def snapshot(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "snapshot", value)

    @property
    @pulumi.getter
    def topic(self) -> Optional[pulumi.Input[str]]:
        """
        The Kafka topic you want to subscribe to.
        """
        return pulumi.get(self, "topic")

    @topic.setter
    def topic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic", value)


class SinkKafka(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 compression_type: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input[pulumi.InputType['SinkKafkaEnvelopeArgs']]] = None,
                 format: Optional[pulumi.Input[pulumi.InputType['SinkKafkaFormatArgs']]] = None,
                 from_: Optional[pulumi.Input[pulumi.InputType['SinkKafkaFromArgs']]] = None,
                 kafka_connection: Optional[pulumi.Input[pulumi.InputType['SinkKafkaKafkaConnectionArgs']]] = None,
                 key_not_enforced: Optional[pulumi.Input[bool]] = None,
                 keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 snapshot: Optional[pulumi.Input[bool]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        A Kafka sink establishes a link to a Kafka cluster that you want Materialize to write data to.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sink_kafka = materialize.SinkKafka("exampleSinkKafka",
            cluster_name="quickstart",
            envelope=materialize.SinkKafkaEnvelopeArgs(
                upsert=True,
            ),
            format=materialize.SinkKafkaFormatArgs(
                avro=materialize.SinkKafkaFormatAvroArgs(
                    schema_registry_connection=materialize.SinkKafkaFormatAvroSchemaRegistryConnectionArgs(
                        database_name="database",
                        name="csr_connection",
                        schema_name="schema",
                    ),
                ),
            ),
            from_=materialize.SinkKafkaFromArgs(
                name="table",
            ),
            kafka_connection=materialize.SinkKafkaKafkaConnectionArgs(
                name="kafka_connection",
            ),
            schema_name="schema",
            topic="test_avro_topic")
        ```

        ## Import

        Sinks can be imported using the sink id

        ```sh
         $ pulumi import materialize:index/sinkKafka:SinkKafka example_sink_kafka <region>:<sink_id>
        ```

         Sink id and information be found in the `mz_catalog.mz_sinks` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this sink.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] compression_type: The type of compression to apply to messages before they are sent to Kafka.
        :param pulumi.Input[str] database_name: The identifier for the sink database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SinkKafkaEnvelopeArgs']] envelope: How to interpret records (e.g. Debezium, Upsert).
        :param pulumi.Input[pulumi.InputType['SinkKafkaFormatArgs']] format: How to decode raw bytes from different formats into data structures it can understand at runtime.
        :param pulumi.Input[pulumi.InputType['SinkKafkaFromArgs']] from_: The name of the source, table or materialized view you want to send to the sink.
        :param pulumi.Input[pulumi.InputType['SinkKafkaKafkaConnectionArgs']] kafka_connection: The name of the Kafka connection to use in the sink.
        :param pulumi.Input[bool] key_not_enforced: Disable Materialize's validation of the key's uniqueness.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] keys: An optional list of columns to use for the Kafka key. If unspecified, the Kafka key is left unset.
        :param pulumi.Input[str] name: The identifier for the sink.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the sink schema. Defaults to `public`.
        :param pulumi.Input[bool] snapshot: Whether to emit the consolidated results of the query before the sink was created at the start of the sink.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SinkKafkaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A Kafka sink establishes a link to a Kafka cluster that you want Materialize to write data to.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sink_kafka = materialize.SinkKafka("exampleSinkKafka",
            cluster_name="quickstart",
            envelope=materialize.SinkKafkaEnvelopeArgs(
                upsert=True,
            ),
            format=materialize.SinkKafkaFormatArgs(
                avro=materialize.SinkKafkaFormatAvroArgs(
                    schema_registry_connection=materialize.SinkKafkaFormatAvroSchemaRegistryConnectionArgs(
                        database_name="database",
                        name="csr_connection",
                        schema_name="schema",
                    ),
                ),
            ),
            from_=materialize.SinkKafkaFromArgs(
                name="table",
            ),
            kafka_connection=materialize.SinkKafkaKafkaConnectionArgs(
                name="kafka_connection",
            ),
            schema_name="schema",
            topic="test_avro_topic")
        ```

        ## Import

        Sinks can be imported using the sink id

        ```sh
         $ pulumi import materialize:index/sinkKafka:SinkKafka example_sink_kafka <region>:<sink_id>
        ```

         Sink id and information be found in the `mz_catalog.mz_sinks` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param SinkKafkaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SinkKafkaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 compression_type: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 envelope: Optional[pulumi.Input[pulumi.InputType['SinkKafkaEnvelopeArgs']]] = None,
                 format: Optional[pulumi.Input[pulumi.InputType['SinkKafkaFormatArgs']]] = None,
                 from_: Optional[pulumi.Input[pulumi.InputType['SinkKafkaFromArgs']]] = None,
                 kafka_connection: Optional[pulumi.Input[pulumi.InputType['SinkKafkaKafkaConnectionArgs']]] = None,
                 key_not_enforced: Optional[pulumi.Input[bool]] = None,
                 keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 snapshot: Optional[pulumi.Input[bool]] = None,
                 topic: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SinkKafkaArgs.__new__(SinkKafkaArgs)

            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["compression_type"] = compression_type
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["envelope"] = envelope
            __props__.__dict__["format"] = format
            if from_ is None and not opts.urn:
                raise TypeError("Missing required property 'from_'")
            __props__.__dict__["from_"] = from_
            if kafka_connection is None and not opts.urn:
                raise TypeError("Missing required property 'kafka_connection'")
            __props__.__dict__["kafka_connection"] = kafka_connection
            __props__.__dict__["key_not_enforced"] = key_not_enforced
            __props__.__dict__["keys"] = keys
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["snapshot"] = snapshot
            if topic is None and not opts.urn:
                raise TypeError("Missing required property 'topic'")
            __props__.__dict__["topic"] = topic
            __props__.__dict__["qualified_sql_name"] = None
            __props__.__dict__["size"] = None
        super(SinkKafka, __self__).__init__(
            'materialize:index/sinkKafka:SinkKafka',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            compression_type: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            envelope: Optional[pulumi.Input[pulumi.InputType['SinkKafkaEnvelopeArgs']]] = None,
            format: Optional[pulumi.Input[pulumi.InputType['SinkKafkaFormatArgs']]] = None,
            from_: Optional[pulumi.Input[pulumi.InputType['SinkKafkaFromArgs']]] = None,
            kafka_connection: Optional[pulumi.Input[pulumi.InputType['SinkKafkaKafkaConnectionArgs']]] = None,
            key_not_enforced: Optional[pulumi.Input[bool]] = None,
            keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[str]] = None,
            snapshot: Optional[pulumi.Input[bool]] = None,
            topic: Optional[pulumi.Input[str]] = None) -> 'SinkKafka':
        """
        Get an existing SinkKafka resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this sink.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] compression_type: The type of compression to apply to messages before they are sent to Kafka.
        :param pulumi.Input[str] database_name: The identifier for the sink database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[pulumi.InputType['SinkKafkaEnvelopeArgs']] envelope: How to interpret records (e.g. Debezium, Upsert).
        :param pulumi.Input[pulumi.InputType['SinkKafkaFormatArgs']] format: How to decode raw bytes from different formats into data structures it can understand at runtime.
        :param pulumi.Input[pulumi.InputType['SinkKafkaFromArgs']] from_: The name of the source, table or materialized view you want to send to the sink.
        :param pulumi.Input[pulumi.InputType['SinkKafkaKafkaConnectionArgs']] kafka_connection: The name of the Kafka connection to use in the sink.
        :param pulumi.Input[bool] key_not_enforced: Disable Materialize's validation of the key's uniqueness.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] keys: An optional list of columns to use for the Kafka key. If unspecified, the Kafka key is left unset.
        :param pulumi.Input[str] name: The identifier for the sink.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the sink.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the sink schema. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this sink.
        :param pulumi.Input[bool] snapshot: Whether to emit the consolidated results of the query before the sink was created at the start of the sink.
        :param pulumi.Input[str] topic: The Kafka topic you want to subscribe to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SinkKafkaState.__new__(_SinkKafkaState)

        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["compression_type"] = compression_type
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["envelope"] = envelope
        __props__.__dict__["format"] = format
        __props__.__dict__["from_"] = from_
        __props__.__dict__["kafka_connection"] = kafka_connection
        __props__.__dict__["key_not_enforced"] = key_not_enforced
        __props__.__dict__["keys"] = keys
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["size"] = size
        __props__.__dict__["snapshot"] = snapshot
        __props__.__dict__["topic"] = topic
        return SinkKafka(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The cluster to maintain this sink.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="compressionType")
    def compression_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of compression to apply to messages before they are sent to Kafka.
        """
        return pulumi.get(self, "compression_type")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the sink database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def envelope(self) -> pulumi.Output[Optional['outputs.SinkKafkaEnvelope']]:
        """
        How to interpret records (e.g. Debezium, Upsert).
        """
        return pulumi.get(self, "envelope")

    @property
    @pulumi.getter
    def format(self) -> pulumi.Output[Optional['outputs.SinkKafkaFormat']]:
        """
        How to decode raw bytes from different formats into data structures it can understand at runtime.
        """
        return pulumi.get(self, "format")

    @property
    @pulumi.getter(name="from")
    def from_(self) -> pulumi.Output['outputs.SinkKafkaFrom']:
        """
        The name of the source, table or materialized view you want to send to the sink.
        """
        return pulumi.get(self, "from_")

    @property
    @pulumi.getter(name="kafkaConnection")
    def kafka_connection(self) -> pulumi.Output['outputs.SinkKafkaKafkaConnection']:
        """
        The name of the Kafka connection to use in the sink.
        """
        return pulumi.get(self, "kafka_connection")

    @property
    @pulumi.getter(name="keyNotEnforced")
    def key_not_enforced(self) -> pulumi.Output[Optional[bool]]:
        """
        Disable Materialize's validation of the key's uniqueness.
        """
        return pulumi.get(self, "key_not_enforced")

    @property
    @pulumi.getter
    def keys(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        An optional list of columns to use for the Kafka key. If unspecified, the Kafka key is left unset.
        """
        return pulumi.get(self, "keys")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the sink.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the sink.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the sink schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[str]:
        """
        The size of the cluster maintaining this sink.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def snapshot(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to emit the consolidated results of the query before the sink was created at the start of the sink.
        """
        return pulumi.get(self, "snapshot")

    @property
    @pulumi.getter
    def topic(self) -> pulumi.Output[str]:
        """
        The Kafka topic you want to subscribe to.
        """
        return pulumi.get(self, "topic")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['SSODefaultRolesArgs', 'SSODefaultRoles']

@pulumi.input_type
class SSODefaultRolesArgs:
    def __init__(__self__, *,
                 roles: pulumi.Input[Sequence[pulumi.Input[str]]],
                 sso_config_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a SSODefaultRoles resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of default role names for the SSO configuration. These roles will be assigned by default to users who sign up via SSO.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        """
        pulumi.set(__self__, "roles", roles)
        pulumi.set(__self__, "sso_config_id", sso_config_id)

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Set of default role names for the SSO configuration. These roles will be assigned by default to users who sign up via SSO.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> pulumi.Input[str]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @sso_config_id.setter
    def sso_config_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "sso_config_id", value)


@pulumi.input_type
class _SSODefaultRolesState:
    def __init__(__self__, *,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sso_config_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SSODefaultRoles resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of default role names for the SSO configuration. These roles will be assigned by default to users who sign up via SSO.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        """
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if sso_config_id is not None:
            pulumi.set(__self__, "sso_config_id", sso_config_id)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of default role names for the SSO configuration. These roles will be assigned by default to users who sign up via SSO.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @sso_config_id.setter
    def sso_config_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sso_config_id", value)


class SSODefaultRoles(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sso_config_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The SSO default roles resource allows you to set the default roles for an SSO configuration. These roles will be assigned to users who sign in with SSO.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_default_roles = materialize.SSODefaultRoles("exampleSsoDefaultRoles",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"],
            roles=["Admin"])
        example_sso_default_roles2 = materialize.SSODefaultRoles("exampleSsoDefaultRoles2",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"],
            roles=[
                "Admin",
                "Member",
            ])
        ```

        ## Import

        Default roles can be imported using the role id, which can be found using the `materialize_sso_config` data source

        ```sh
         $ pulumi import materialize:index/sSODefaultRoles:SSODefaultRoles example_role <role_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of default role names for the SSO configuration. These roles will be assigned by default to users who sign up via SSO.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SSODefaultRolesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The SSO default roles resource allows you to set the default roles for an SSO configuration. These roles will be assigned to users who sign in with SSO.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_default_roles = materialize.SSODefaultRoles("exampleSsoDefaultRoles",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"],
            roles=["Admin"])
        example_sso_default_roles2 = materialize.SSODefaultRoles("exampleSsoDefaultRoles2",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"],
            roles=[
                "Admin",
                "Member",
            ])
        ```

        ## Import

        Default roles can be imported using the role id, which can be found using the `materialize_sso_config` data source

        ```sh
         $ pulumi import materialize:index/sSODefaultRoles:SSODefaultRoles example_role <role_id>
        ```

        :param str resource_name: The name of the resource.
        :param SSODefaultRolesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SSODefaultRolesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sso_config_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SSODefaultRolesArgs.__new__(SSODefaultRolesArgs)

            if roles is None and not opts.urn:
                raise TypeError("Missing required property 'roles'")
            __props__.__dict__["roles"] = roles
            if sso_config_id is None and not opts.urn:
                raise TypeError("Missing required property 'sso_config_id'")
            __props__.__dict__["sso_config_id"] = sso_config_id
        super(SSODefaultRoles, __self__).__init__(
            'materialize:index/sSODefaultRoles:SSODefaultRoles',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            sso_config_id: Optional[pulumi.Input[str]] = None) -> 'SSODefaultRoles':
        """
        Get an existing SSODefaultRoles resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: Set of default role names for the SSO configuration. These roles will be assigned by default to users who sign up via SSO.
        :param pulumi.Input[str] sso_config_id: The ID of the associated SSO configuration.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SSODefaultRolesState.__new__(_SSODefaultRolesState)

        __props__.__dict__["roles"] = roles
        __props__.__dict__["sso_config_id"] = sso_config_id
        return SSODefaultRoles(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of default role names for the SSO configuration. These roles will be assigned by default to users who sign up via SSO.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> pulumi.Output[str]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetIndexesResult',
    'AwaitableGetIndexesResult',
    'get_indexes',
    'get_indexes_output',
]

@pulumi.output_type
class GetIndexesResult:
    """
    A collection of values returned by GetIndexes.
    """
    def __init__(__self__, database_name=None, id=None, indexes=None, region=None, schema_name=None):
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if indexes and not isinstance(indexes, list):
            raise TypeError("Expected argument 'indexes' to be a list")
        pulumi.set(__self__, "indexes", indexes)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if schema_name and not isinstance(schema_name, str):
            raise TypeError("Expected argument 'schema_name' to be a str")
        pulumi.set(__self__, "schema_name", schema_name)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[str]:
        """
        Limit indexes to a specific database
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def indexes(self) -> Sequence['outputs.GetIndexesIndexResult']:
        """
        The indexes in the account
        """
        return pulumi.get(self, "indexes")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[str]:
        """
        Limit indexes to a specific schema within a specific database
        """
        return pulumi.get(self, "schema_name")


class AwaitableGetIndexesResult(GetIndexesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIndexesResult(
            database_name=self.database_name,
            id=self.id,
            indexes=self.indexes,
            region=self.region,
            schema_name=self.schema_name)


def get_indexes(database_name: Optional[str] = None,
                schema_name: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIndexesResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_indexes()
    materialize = materialize.get_indexes(database_name="materialize")
    materialize_schema = materialize.get_indexes(database_name="materialize",
        schema_name="schema")
    ```


    :param str database_name: Limit indexes to a specific database
    :param str schema_name: Limit indexes to a specific schema within a specific database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getIndexes:GetIndexes', __args__, opts=opts, typ=GetIndexesResult).value

    return AwaitableGetIndexesResult(
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        indexes=pulumi.get(__ret__, 'indexes'),
        region=pulumi.get(__ret__, 'region'),
        schema_name=pulumi.get(__ret__, 'schema_name'))


@_utilities.lift_output_func(get_indexes)
def get_indexes_output(database_name: Optional[pulumi.Input[Optional[str]]] = None,
                       schema_name: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIndexesResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_indexes()
    materialize = materialize.get_indexes(database_name="materialize")
    materialize_schema = materialize.get_indexes(database_name="materialize",
        schema_name="schema")
    ```


    :param str database_name: Limit indexes to a specific database
    :param str schema_name: Limit indexes to a specific schema within a specific database
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SourceWebhookArgs', 'SourceWebhook']

@pulumi.input_type
class SourceWebhookArgs:
    def __init__(__self__, *,
                 body_format: pulumi.Input[str],
                 check_expression: Optional[pulumi.Input[str]] = None,
                 check_options: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 include_header: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]]] = None,
                 include_headers: Optional[pulumi.Input['SourceWebhookIncludeHeadersArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SourceWebhook resource.
        :param pulumi.Input[str] body_format: The body format of the webhook.
        :param pulumi.Input[str] check_expression: The check expression for the webhook.
        :param pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]] check_options: The check options for the webhook.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]] include_header: Map a header value from a request into a column.
        :param pulumi.Input['SourceWebhookIncludeHeadersArgs'] include_headers: Include headers in the webhook.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema. Defaults to `public`.
        """
        pulumi.set(__self__, "body_format", body_format)
        if check_expression is not None:
            pulumi.set(__self__, "check_expression", check_expression)
        if check_options is not None:
            pulumi.set(__self__, "check_options", check_options)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if include_header is not None:
            pulumi.set(__self__, "include_header", include_header)
        if include_headers is not None:
            pulumi.set(__self__, "include_headers", include_headers)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)

    @property
    @pulumi.getter(name="bodyFormat")
    def body_format(self) -> pulumi.Input[str]:
        """
        The body format of the webhook.
        """
        return pulumi.get(self, "body_format")

    @body_format.setter
    def body_format(self, value: pulumi.Input[str]):
        pulumi.set(self, "body_format", value)

    @property
    @pulumi.getter(name="checkExpression")
    def check_expression(self) -> Optional[pulumi.Input[str]]:
        """
        The check expression for the webhook.
        """
        return pulumi.get(self, "check_expression")

    @check_expression.setter
    def check_expression(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "check_expression", value)

    @property
    @pulumi.getter(name="checkOptions")
    def check_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]]]:
        """
        The check options for the webhook.
        """
        return pulumi.get(self, "check_options")

    @check_options.setter
    def check_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]]]):
        pulumi.set(self, "check_options", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="includeHeader")
    def include_header(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]]]:
        """
        Map a header value from a request into a column.
        """
        return pulumi.get(self, "include_header")

    @include_header.setter
    def include_header(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]]]):
        pulumi.set(self, "include_header", value)

    @property
    @pulumi.getter(name="includeHeaders")
    def include_headers(self) -> Optional[pulumi.Input['SourceWebhookIncludeHeadersArgs']]:
        """
        Include headers in the webhook.
        """
        return pulumi.get(self, "include_headers")

    @include_headers.setter
    def include_headers(self, value: Optional[pulumi.Input['SourceWebhookIncludeHeadersArgs']]):
        pulumi.set(self, "include_headers", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)


@pulumi.input_type
class _SourceWebhookState:
    def __init__(__self__, *,
                 body_format: Optional[pulumi.Input[str]] = None,
                 check_expression: Optional[pulumi.Input[str]] = None,
                 check_options: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 include_header: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]]] = None,
                 include_headers: Optional[pulumi.Input['SourceWebhookIncludeHeadersArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 qualified_sql_name: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[str]] = None,
                 subsources: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookSubsourceArgs']]]] = None):
        """
        Input properties used for looking up and filtering SourceWebhook resources.
        :param pulumi.Input[str] body_format: The body format of the webhook.
        :param pulumi.Input[str] check_expression: The check expression for the webhook.
        :param pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]] check_options: The check options for the webhook.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]] include_header: Map a header value from a request into a column.
        :param pulumi.Input['SourceWebhookIncludeHeadersArgs'] include_headers: Include headers in the webhook.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[Sequence[pulumi.Input['SourceWebhookSubsourceArgs']]] subsources: Subsources of a source.
        """
        if body_format is not None:
            pulumi.set(__self__, "body_format", body_format)
        if check_expression is not None:
            pulumi.set(__self__, "check_expression", check_expression)
        if check_options is not None:
            pulumi.set(__self__, "check_options", check_options)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if include_header is not None:
            pulumi.set(__self__, "include_header", include_header)
        if include_headers is not None:
            pulumi.set(__self__, "include_headers", include_headers)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if qualified_sql_name is not None:
            pulumi.set(__self__, "qualified_sql_name", qualified_sql_name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if subsources is not None:
            pulumi.set(__self__, "subsources", subsources)

    @property
    @pulumi.getter(name="bodyFormat")
    def body_format(self) -> Optional[pulumi.Input[str]]:
        """
        The body format of the webhook.
        """
        return pulumi.get(self, "body_format")

    @body_format.setter
    def body_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "body_format", value)

    @property
    @pulumi.getter(name="checkExpression")
    def check_expression(self) -> Optional[pulumi.Input[str]]:
        """
        The check expression for the webhook.
        """
        return pulumi.get(self, "check_expression")

    @check_expression.setter
    def check_expression(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "check_expression", value)

    @property
    @pulumi.getter(name="checkOptions")
    def check_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]]]:
        """
        The check options for the webhook.
        """
        return pulumi.get(self, "check_options")

    @check_options.setter
    def check_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookCheckOptionArgs']]]]):
        pulumi.set(self, "check_options", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="includeHeader")
    def include_header(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]]]:
        """
        Map a header value from a request into a column.
        """
        return pulumi.get(self, "include_header")

    @include_header.setter
    def include_header(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookIncludeHeaderArgs']]]]):
        pulumi.set(self, "include_header", value)

    @property
    @pulumi.getter(name="includeHeaders")
    def include_headers(self) -> Optional[pulumi.Input['SourceWebhookIncludeHeadersArgs']]:
        """
        Include headers in the webhook.
        """
        return pulumi.get(self, "include_headers")

    @include_headers.setter
    def include_headers(self, value: Optional[pulumi.Input['SourceWebhookIncludeHeadersArgs']]):
        pulumi.set(self, "include_headers", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ownership_role", value)

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @qualified_sql_name.setter
    def qualified_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualified_sql_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[str]]:
        """
        The identifier for the source schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[str]]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def subsources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookSubsourceArgs']]]]:
        """
        Subsources of a source.
        """
        return pulumi.get(self, "subsources")

    @subsources.setter
    def subsources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SourceWebhookSubsourceArgs']]]]):
        pulumi.set(self, "subsources", value)


class SourceWebhook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body_format: Optional[pulumi.Input[str]] = None,
                 check_expression: Optional[pulumi.Input[str]] = None,
                 check_options: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookCheckOptionArgs']]]]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 include_header: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeaderArgs']]]]] = None,
                 include_headers: Optional[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeadersArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        **Private Preview** A webhook source describes a webhook you want Materialize to read data from.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_webhook = materialize.SourceWebhook("exampleWebhook",
            cluster_name=materialize_cluster["cluster"]["name"],
            body_format="json",
            check_expression="headers->'x-mz-api-key' = secret",
            include_headers=materialize.SourceWebhookIncludeHeadersArgs(
                nots=["x-mz-api-key"],
            ),
            check_options=[
                materialize.SourceWebhookCheckOptionArgs(
                    field=materialize.SourceWebhookCheckOptionFieldArgs(
                        headers=True,
                    ),
                ),
                materialize.SourceWebhookCheckOptionArgs(
                    field=materialize.SourceWebhookCheckOptionFieldArgs(
                        secret=materialize.SourceWebhookCheckOptionFieldSecretArgs(
                            name=materialize_secret["password"]["name"],
                            database_name=materialize_secret["password"]["database_name"],
                            schema_name=materialize_secret["password"]["schema_name"],
                        ),
                    ),
                    alias="secret",
                ),
            ])
        ```

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourceWebhook:SourceWebhook example_source_webhook <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body_format: The body format of the webhook.
        :param pulumi.Input[str] check_expression: The check expression for the webhook.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookCheckOptionArgs']]]] check_options: The check options for the webhook.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeaderArgs']]]] include_header: Map a header value from a request into a column.
        :param pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeadersArgs']] include_headers: Include headers in the webhook.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema. Defaults to `public`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SourceWebhookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        **Private Preview** A webhook source describes a webhook you want Materialize to read data from.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_webhook = materialize.SourceWebhook("exampleWebhook",
            cluster_name=materialize_cluster["cluster"]["name"],
            body_format="json",
            check_expression="headers->'x-mz-api-key' = secret",
            include_headers=materialize.SourceWebhookIncludeHeadersArgs(
                nots=["x-mz-api-key"],
            ),
            check_options=[
                materialize.SourceWebhookCheckOptionArgs(
                    field=materialize.SourceWebhookCheckOptionFieldArgs(
                        headers=True,
                    ),
                ),
                materialize.SourceWebhookCheckOptionArgs(
                    field=materialize.SourceWebhookCheckOptionFieldArgs(
                        secret=materialize.SourceWebhookCheckOptionFieldSecretArgs(
                            name=materialize_secret["password"]["name"],
                            database_name=materialize_secret["password"]["database_name"],
                            schema_name=materialize_secret["password"]["schema_name"],
                        ),
                    ),
                    alias="secret",
                ),
            ])
        ```

        ## Import

        Sources can be imported using the source id

        ```sh
         $ pulumi import materialize:index/sourceWebhook:SourceWebhook example_source_webhook <region>:<source_id>
        ```

         Source id and information be found in the `mz_catalog.mz_sources` table The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param SourceWebhookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SourceWebhookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body_format: Optional[pulumi.Input[str]] = None,
                 check_expression: Optional[pulumi.Input[str]] = None,
                 check_options: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookCheckOptionArgs']]]]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 include_header: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeaderArgs']]]]] = None,
                 include_headers: Optional[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeadersArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 ownership_role: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 schema_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SourceWebhookArgs.__new__(SourceWebhookArgs)

            if body_format is None and not opts.urn:
                raise TypeError("Missing required property 'body_format'")
            __props__.__dict__["body_format"] = body_format
            __props__.__dict__["check_expression"] = check_expression
            __props__.__dict__["check_options"] = check_options
            __props__.__dict__["cluster_name"] = cluster_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["database_name"] = database_name
            __props__.__dict__["include_header"] = include_header
            __props__.__dict__["include_headers"] = include_headers
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["qualified_sql_name"] = None
            __props__.__dict__["size"] = None
            __props__.__dict__["subsources"] = None
        super(SourceWebhook, __self__).__init__(
            'materialize:index/sourceWebhook:SourceWebhook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            body_format: Optional[pulumi.Input[str]] = None,
            check_expression: Optional[pulumi.Input[str]] = None,
            check_options: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookCheckOptionArgs']]]]] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            include_header: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeaderArgs']]]]] = None,
            include_headers: Optional[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeadersArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            ownership_role: Optional[pulumi.Input[str]] = None,
            qualified_sql_name: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            schema_name: Optional[pulumi.Input[str]] = None,
            size: Optional[pulumi.Input[str]] = None,
            subsources: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookSubsourceArgs']]]]] = None) -> 'SourceWebhook':
        """
        Get an existing SourceWebhook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body_format: The body format of the webhook.
        :param pulumi.Input[str] check_expression: The check expression for the webhook.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookCheckOptionArgs']]]] check_options: The check options for the webhook.
        :param pulumi.Input[str] cluster_name: The cluster to maintain this source.
        :param pulumi.Input[str] comment: **Public Preview** Comment on an object in the database.
        :param pulumi.Input[str] database_name: The identifier for the source database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeaderArgs']]]] include_header: Map a header value from a request into a column.
        :param pulumi.Input[pulumi.InputType['SourceWebhookIncludeHeadersArgs']] include_headers: Include headers in the webhook.
        :param pulumi.Input[str] name: The identifier for the source.
        :param pulumi.Input[str] ownership_role: The owernship role of the object.
        :param pulumi.Input[str] qualified_sql_name: The fully qualified name of the source.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] schema_name: The identifier for the source schema. Defaults to `public`.
        :param pulumi.Input[str] size: The size of the cluster maintaining this source.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SourceWebhookSubsourceArgs']]]] subsources: Subsources of a source.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SourceWebhookState.__new__(_SourceWebhookState)

        __props__.__dict__["body_format"] = body_format
        __props__.__dict__["check_expression"] = check_expression
        __props__.__dict__["check_options"] = check_options
        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["include_header"] = include_header
        __props__.__dict__["include_headers"] = include_headers
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["qualified_sql_name"] = qualified_sql_name
        __props__.__dict__["region"] = region
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["size"] = size
        __props__.__dict__["subsources"] = subsources
        return SourceWebhook(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bodyFormat")
    def body_format(self) -> pulumi.Output[str]:
        """
        The body format of the webhook.
        """
        return pulumi.get(self, "body_format")

    @property
    @pulumi.getter(name="checkExpression")
    def check_expression(self) -> pulumi.Output[Optional[str]]:
        """
        The check expression for the webhook.
        """
        return pulumi.get(self, "check_expression")

    @property
    @pulumi.getter(name="checkOptions")
    def check_options(self) -> pulumi.Output[Optional[Sequence['outputs.SourceWebhookCheckOption']]]:
        """
        The check options for the webhook.
        """
        return pulumi.get(self, "check_options")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[Optional[str]]:
        """
        The cluster to maintain this source.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        **Public Preview** Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source database. Defaults to `MZ_DATABASE` environment variable if set or `materialize` if environment variable is not set.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="includeHeader")
    def include_header(self) -> pulumi.Output[Optional[Sequence['outputs.SourceWebhookIncludeHeader']]]:
        """
        Map a header value from a request into a column.
        """
        return pulumi.get(self, "include_header")

    @property
    @pulumi.getter(name="includeHeaders")
    def include_headers(self) -> pulumi.Output[Optional['outputs.SourceWebhookIncludeHeaders']]:
        """
        Include headers in the webhook.
        """
        return pulumi.get(self, "include_headers")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The identifier for the source.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @property
    @pulumi.getter(name="qualifiedSqlName")
    def qualified_sql_name(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the source.
        """
        return pulumi.get(self, "qualified_sql_name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[Optional[str]]:
        """
        The identifier for the source schema. Defaults to `public`.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[str]:
        """
        The size of the cluster maintaining this source.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def subsources(self) -> pulumi.Output[Sequence['outputs.SourceWebhookSubsource']]:
        """
        Subsources of a source.
        """
        return pulumi.get(self, "subsources")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('materialize')


class _ExportableConfig(types.ModuleType):
    @property
    def base_endpoint(self) -> Optional[str]:
        """
        The base endpoint for Materialize.
        """
        return __config__.get('baseEndpoint') or _utilities.get_env('MZ_BASE_ENDPOINT')

    @property
    def cloud_endpoint(self) -> Optional[str]:
        """
        The endpoint for the Materialize Cloud API.
        """
        return __config__.get('cloudEndpoint') or _utilities.get_env('MZ_CLOUD_ENDPOINT')

    @property
    def database(self) -> Optional[str]:
        """
        The Materialize database. Can also come from the `MZ_DATABASE` environment variable. Defaults to `materialize`.
        """
        return __config__.get('database') or _utilities.get_env('MZ_DATABASE')

    @property
    def default_region(self) -> Optional[str]:
        """
        The default region if not specified in the resource
        """
        return __config__.get('defaultRegion') or _utilities.get_env('MZ_DEFAULT_REGION')

    @property
    def endpoint(self) -> Optional[str]:
        """
        The endpoint for the Materialize API.
        """
        return __config__.get('endpoint') or _utilities.get_env('MZ_ENDPOINT')

    @property
    def password(self) -> Optional[str]:
        """
        Materialize host. Can also come from the `MZ_PASSWORD` environment variable.
        """
        return __config__.get('password') or _utilities.get_env('MZ_PASSWORD')

    @property
    def sslmode(self) -> Optional[str]:
        """
        For testing purposes, the SSL mode to use.
        """
        return __config__.get('sslmode') or _utilities.get_env('MZ_SSLMODE')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 roles: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "roles", roles)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        The email address of the user. This must be unique across all users in the organization.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "roles", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 auth_provider: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 verified: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[str] auth_provider: The authentication provider for the user.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        if auth_provider is not None:
            pulumi.set(__self__, "auth_provider", auth_provider)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if verified is not None:
            pulumi.set(__self__, "verified", verified)

    @property
    @pulumi.getter(name="authProvider")
    def auth_provider(self) -> Optional[pulumi.Input[str]]:
        """
        The authentication provider for the user.
        """
        return pulumi.get(self, "auth_provider")

    @auth_provider.setter
    def auth_provider(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_provider", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        The email address of the user. This must be unique across all users in the organization.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter
    def verified(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "verified")

    @verified.setter
    def verified(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "verified", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_user = materialize.User("exampleUser",
            email="example-user@example.com",
            roles=[
                "Member",
                "Admin",
            ])
        ```

        ## Import

        Users can be imported using the user id

        ```sh
         $ pulumi import materialize:index/user:User example_user <user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_user = materialize.User("exampleUser",
            email="example-user@example.com",
            roles=[
                "Member",
                "Admin",
            ])
        ```

        ## Import

        Users can be imported using the user id

        ```sh
         $ pulumi import materialize:index/user:User example_user <user_id>
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            if roles is None and not opts.urn:
                raise TypeError("Missing required property 'roles'")
            __props__.__dict__["roles"] = roles
            __props__.__dict__["auth_provider"] = None
            __props__.__dict__["metadata"] = None
            __props__.__dict__["verified"] = None
        super(User, __self__).__init__(
            'materialize:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_provider: Optional[pulumi.Input[str]] = None,
            email: Optional[pulumi.Input[str]] = None,
            metadata: Optional[pulumi.Input[str]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            verified: Optional[pulumi.Input[bool]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_provider: The authentication provider for the user.
        :param pulumi.Input[str] email: The email address of the user. This must be unique across all users in the organization.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] roles: The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["auth_provider"] = auth_provider
        __props__.__dict__["email"] = email
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["roles"] = roles
        __props__.__dict__["verified"] = verified
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authProvider")
    def auth_provider(self) -> pulumi.Output[str]:
        """
        The authentication provider for the user.
        """
        return pulumi.get(self, "auth_provider")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        The email address of the user. This must be unique across all users in the organization.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[str]:
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence[str]]:
        """
        The roles to assign to the user. Allowed values are 'Member' and 'Admin'.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def verified(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "verified")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['GrantDatabaseArgs', 'GrantDatabase']

@pulumi.input_type
class GrantDatabaseArgs:
    def __init__(__self__, *,
                 database_name: pulumi.Input[str],
                 privilege: pulumi.Input[str],
                 role_name: pulumi.Input[str],
                 region: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a GrantDatabase resource.
        :param pulumi.Input[str] database_name: The database that is being granted on.
        :param pulumi.Input[str] privilege: The privilege to grant to the object.
        :param pulumi.Input[str] role_name: The name of the role to grant privilege to.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        pulumi.set(__self__, "database_name", database_name)
        pulumi.set(__self__, "privilege", privilege)
        pulumi.set(__self__, "role_name", role_name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Input[str]:
        """
        The database that is being granted on.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def privilege(self) -> pulumi.Input[str]:
        """
        The privilege to grant to the object.
        """
        return pulumi.get(self, "privilege")

    @privilege.setter
    def privilege(self, value: pulumi.Input[str]):
        pulumi.set(self, "privilege", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[str]:
        """
        The name of the role to grant privilege to.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _GrantDatabaseState:
    def __init__(__self__, *,
                 database_name: Optional[pulumi.Input[str]] = None,
                 privilege: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 role_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GrantDatabase resources.
        :param pulumi.Input[str] database_name: The database that is being granted on.
        :param pulumi.Input[str] privilege: The privilege to grant to the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] role_name: The name of the role to grant privilege to.
        """
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if privilege is not None:
            pulumi.set(__self__, "privilege", privilege)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        The database that is being granted on.
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter
    def privilege(self) -> Optional[pulumi.Input[str]]:
        """
        The privilege to grant to the object.
        """
        return pulumi.get(self, "privilege")

    @privilege.setter
    def privilege(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "privilege", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the role to grant privilege to.
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_name", value)


class GrantDatabase(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 privilege: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages the privileges on a Materailize database for roles.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Grant USAGE to role example_role to database example_database
        database_grant_usage = materialize.GrantDatabase("databaseGrantUsage",
            database_name="example_database",
            privilege="USAGE",
            role_name="example_role")
        ```

        ## Import

        #Grants can be imported using the concatenation of GRANT, the object type, the id of the object, the id of the role and the privilege

        ```sh
         $ pulumi import materialize:index/grantDatabase:GrantDatabase example <region>:GRANT|DATABASE|<database_id>|<role_id>|<privilege>
        ```

         The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] database_name: The database that is being granted on.
        :param pulumi.Input[str] privilege: The privilege to grant to the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] role_name: The name of the role to grant privilege to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GrantDatabaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the privileges on a Materailize database for roles.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Grant USAGE to role example_role to database example_database
        database_grant_usage = materialize.GrantDatabase("databaseGrantUsage",
            database_name="example_database",
            privilege="USAGE",
            role_name="example_role")
        ```

        ## Import

        #Grants can be imported using the concatenation of GRANT, the object type, the id of the object, the id of the role and the privilege

        ```sh
         $ pulumi import materialize:index/grantDatabase:GrantDatabase example <region>:GRANT|DATABASE|<database_id>|<role_id>|<privilege>
        ```

         The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param GrantDatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GrantDatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 privilege: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GrantDatabaseArgs.__new__(GrantDatabaseArgs)

            if database_name is None and not opts.urn:
                raise TypeError("Missing required property 'database_name'")
            __props__.__dict__["database_name"] = database_name
            if privilege is None and not opts.urn:
                raise TypeError("Missing required property 'privilege'")
            __props__.__dict__["privilege"] = privilege
            __props__.__dict__["region"] = region
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
        super(GrantDatabase, __self__).__init__(
            'materialize:index/grantDatabase:GrantDatabase',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            privilege: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            role_name: Optional[pulumi.Input[str]] = None) -> 'GrantDatabase':
        """
        Get an existing GrantDatabase resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] database_name: The database that is being granted on.
        :param pulumi.Input[str] privilege: The privilege to grant to the object.
        :param pulumi.Input[str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[str] role_name: The name of the role to grant privilege to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GrantDatabaseState.__new__(_GrantDatabaseState)

        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["privilege"] = privilege
        __props__.__dict__["region"] = region
        __props__.__dict__["role_name"] = role_name
        return GrantDatabase(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[str]:
        """
        The database that is being granted on.
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter
    def privilege(self) -> pulumi.Output[str]:
        """
        The privilege to grant to the object.
        """
        return pulumi.get(self, "privilege")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[str]:
        """
        The name of the role to grant privilege to.
        """
        return pulumi.get(self, "role_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['AppPasswordArgs', 'AppPassword']

@pulumi.input_type
class AppPasswordArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AppPassword resource.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AppPasswordState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AppPassword resources.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


class AppPassword(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_app_password = materialize.AppPassword("exampleAppPassword")
        ```

        ## Import

        App passwords can be imported using the app password id

        ```sh
         $ pulumi import materialize:index/appPassword:AppPassword example_app_password <app_password_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AppPasswordArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_app_password = materialize.AppPassword("exampleAppPassword")
        ```

        ## Import

        App passwords can be imported using the app password id

        ```sh
         $ pulumi import materialize:index/appPassword:AppPassword example_app_password <app_password_id>
        ```

        :param str resource_name: The name of the resource.
        :param AppPasswordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppPasswordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppPasswordArgs.__new__(AppPasswordArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["created_at"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["password"] = None
            __props__.__dict__["secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password", "secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(AppPassword, __self__).__init__(
            'materialize:index/appPassword:AppPassword',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            secret: Optional[pulumi.Input[str]] = None) -> 'AppPassword':
        """
        Get an existing AppPassword resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppPasswordState.__new__(_AppPasswordState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["name"] = name
        __props__.__dict__["owner"] = owner
        __props__.__dict__["password"] = password
        __props__.__dict__["secret"] = secret
        return AppPassword(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Output[str]:
        return pulumi.get(self, "secret")

